column_sql

Function column_sql 

pub fn column_sql(c: &ColumnDef, auto_pk: bool) -> String
One column definition line. auto_pk says whether this table uses the conventional id: i64 surrogate key (rendered inline as INTEGER PRIMARY KEY AUTOINCREMENT); composite keys are rendered as a table constraint by create_table_sql instead.